@@ -144,8 +144,8 @@ normalize.grouped_df <- function(x,
   )
 
   info <- attributes(x)
-  # dplyr >= 0.8.0 returns attribute "indices"
-  grps <- attr(x, "groups", exact = TRUE)
+  # works only for dplyr >= 0.8.0
+  grps <- attr(x, "groups", exact = TRUE)[[".rows"]]
 
   # check for formula notation, convert to character vector
   if (inherits(select, "formula")) {
@@ -155,14 +155,6 @@ normalize.grouped_df <- function(x,
     exclude <- all.vars(exclude)
   }
 
-  # dplyr < 0.8.0?
-  if (is.null(grps)) {
-    grps <- attr(x, "indices", exact = TRUE)
-    grps <- lapply(grps, function(x) x + 1)
-  } else {
-    grps <- grps[[".rows"]]
-  }
-
   x <- as.data.frame(x)
   for (rows in grps) {
     x[rows, ] <- normalize(
