@@ -2,17 +2,33 @@ data(efc)
 
 test_that("data_tabulate factor", {
   x <- data_tabulate(efc$e42dep)
-  expect_equal(as.vector(x$Value), as.vector(sort(unique(addNA(efc$e42dep)))))
+  expect_equal(as.vector(x$Value), as.vector(sort(unique(
+    addNA(efc$e42dep)
+  ))))
   expect_equal(x$N, as.vector(table(addNA(efc$e42dep))))
-  expect_equal(x$`Valid %`, as.vector(c(100 * table(efc$e42dep) / sum(!is.na(efc$e42dep)), NA)), ignore_attr = TRUE, tolerance = 1e-3)
+  expect_equal(x$`Valid %`,
+    as.vector(c(
+      100 * table(efc$e42dep) / sum(!is.na(efc$e42dep)), NA
+    )),
+    ignore_attr = TRUE,
+    tolerance = 1e-3
+  )
 })
 
 
 test_that("data_tabulate numeric", {
   x <- data_tabulate(efc$neg_c_7)
-  expect_equal(as.vector(x$Value), as.vector(sort(unique(addNA(efc$neg_c_7)))))
+  expect_equal(as.vector(x$Value), as.vector(sort(unique(
+    addNA(efc$neg_c_7)
+  ))))
   expect_equal(x$N, as.vector(table(addNA(efc$neg_c_7))))
-  expect_equal(x$`Valid %`, as.vector(c(100 * table(efc$neg_c_7) / sum(!is.na(efc$neg_c_7)), NA)), ignore_attr = TRUE, tolerance = 1e-3)
+  expect_equal(x$`Valid %`,
+    as.vector(c(
+      100 * table(efc$neg_c_7) / sum(!is.na(efc$neg_c_7)), NA
+    )),
+    ignore_attr = TRUE,
+    tolerance = 1e-3
+  )
 })
 
 
@@ -26,10 +42,16 @@ test_that("data_tabulate data.frame", {
       names = c(
         "Variable", "Value", "N", "Raw %", "Valid %",
         "Cumulative %"
-      ), class = c("dw_data_tabulate", "data.frame"),
-      row.names = 1:3, type = "numeric", varname = "e16sex",
-      label = "elder's gender", object = "e16sex",
-      duplicate_varnames = c(FALSE, TRUE, TRUE), total_n = 100L, valid_n = 100L
+      ),
+      class = c("dw_data_tabulate", "data.frame"),
+      row.names = 1:3,
+      type = "numeric",
+      varname = "e16sex",
+      label = "elder's gender",
+      object = "e16sex",
+      duplicate_varnames = c(FALSE, TRUE, TRUE),
+      total_n = 100L,
+      valid_n = 100L
     )
   )
   expect_equal(
@@ -38,17 +60,30 @@ test_that("data_tabulate data.frame", {
       names = c(
         "Variable", "Value", "N", "Raw %", "Valid %",
         "Cumulative %"
-      ), class = c("dw_data_tabulate", "data.frame"),
-      row.names = 1:4, type = "numeric", varname = "c172code",
-      label = "carer's level of education", object = "c172code",
+      ),
+      class = c("dw_data_tabulate", "data.frame"),
+      row.names = 1:4,
+      type = "numeric",
+      varname = "c172code",
+      label = "carer's level of education",
+      object = "c172code",
       duplicate_varnames = c(FALSE, TRUE, TRUE, TRUE),
-      total_n = 100L, valid_n = 90L
+      total_n = 100L,
+      valid_n = 90L
     )
   )
   table1 <- x[[1]]
-  expect_equal(as.vector(table1$Value), as.character(c(sort(unique(efc$e16sex)), NA)))
+  expect_equal(as.vector(table1$Value), as.character(c(sort(
+    unique(efc$e16sex)
+  ), NA)))
   expect_equal(table1$N, as.vector(table(addNA(efc$e16sex))))
-  expect_equal(table1$`Valid %`, as.vector(c(100 * table(efc$e16sex) / sum(!is.na(efc$e16sex)), NA)), ignore_attr = TRUE, tolerance = 1e-3)
+  expect_equal(table1$`Valid %`,
+    as.vector(c(
+      100 * table(efc$e16sex) / sum(!is.na(efc$e16sex)), NA
+    )),
+    ignore_attr = TRUE,
+    tolerance = 1e-3
+  )
 })
 
 
@@ -61,9 +96,13 @@ test_that("data_tabulate print", {
     list(
       names = c("Variable", "Value", "N", "Raw %", "Valid %", "Cumulative %"),
       class = c("dw_data_tabulate", "data.frame"),
-      row.names = 1:4, type = "integer", varname = "Large Number",
-      object = "x", duplicate_varnames = c(FALSE, TRUE, TRUE, TRUE),
-      total_n = 1000000L, valid_n = 1000000L
+      row.names = 1:4,
+      type = "integer",
+      varname = "Large Number",
+      object = "x",
+      duplicate_varnames = c(FALSE, TRUE, TRUE, TRUE),
+      total_n = 1000000L,
+      valid_n = 1000000L
     )
   )
 })
@@ -213,19 +252,43 @@ if (requireNamespace("poorman", quietly = TRUE)) {
       attributes(x[[1]]),
       list(
         names = c(
-          "Variable", "Group", "Value", "N", "Raw %", "Valid %",
+          "Variable",
+          "Group",
+          "Value",
+          "N",
+          "Raw %",
+          "Valid %",
           "Cumulative %"
-        ), class = c("dw_data_tabulate", "data.frame"),
-        row.names = 1:4, type = "numeric", varname = "c172code",
-        label = "carer's level of education", object = "c172code",
-        group_variable = structure(list(e16sex = 1), .drop = TRUE, row.names = 1L, class = "data.frame"),
-        duplicate_varnames = c(FALSE, TRUE, TRUE, TRUE), total_n = 46L, valid_n = 41L
+        ),
+        class = c("dw_data_tabulate", "data.frame"),
+        row.names = 1:4,
+        type = "numeric",
+        varname = "c172code",
+        label = "carer's level of education",
+        object = "c172code",
+        group_variable = structure(
+          list(e16sex = 1),
+          .drop = TRUE,
+          row.names = 1L,
+          class = "data.frame"
+        ),
+        duplicate_varnames = c(FALSE, TRUE, TRUE, TRUE),
+        total_n = 46L,
+        valid_n = 41L
       )
     )
     table1 <- x[[1]]
-    expect_equal(as.vector(table1$Value), as.character(c(sort(unique(efc$c172code)), NA)))
+    expect_equal(as.vector(table1$Value), as.character(c(sort(
+      unique(efc$c172code)
+    ), NA)))
     expect_equal(table1$N, as.vector(table(addNA(efc$c172code[efc$e16sex == 1]))))
-    expect_equal(table1$`Valid %`, as.vector(c(100 * table(efc$c172code[efc$e16sex == 1]) / sum(!is.na(efc$c172code[efc$e16sex == 1])), NA)), ignore_attr = TRUE, tolerance = 1e-3)
+    expect_equal(table1$`Valid %`,
+      as.vector(c(
+        100 * table(efc$c172code[efc$e16sex == 1]) / sum(!is.na(efc$c172code[efc$e16sex == 1])), NA
+      )),
+      ignore_attr = TRUE,
+      tolerance = 1e-3
+    )
   })
 
 
@@ -249,7 +312,8 @@ if (requireNamespace("poorman", quietly = TRUE)) {
         "carer's level of education (c172code) <numeric>",
         "Grouped by e16sex (2)",
         "# total N=54 valid N=49",
-        "", "Value |  N | Raw % | Valid % | Cumulative %",
+        "",
+        "Value |  N | Raw % | Valid % | Cumulative %",
         "------+----+-------+---------+-------------",
         "1     |  3 |  5.56 |    6.12 |         6.12",
         "2     | 34 | 62.96 |   69.39 |        75.51",
@@ -259,54 +323,67 @@ if (requireNamespace("poorman", quietly = TRUE)) {
     )
   })
 
-  if (packageVersion("insight") > "0.17.0") {
-    test_that("data_tabulate print, collapse groups", {
-      x <- data_tabulate(poorman::group_by(efc, e16sex), "c172code", collapse = TRUE)
-      out <- capture.output(print(x))
-      expect_equal(
-        out,
-        c(
-          "# Frequency Table",
-          "",
-          "Variable |      Group | Value |  N | Raw % | Valid % | Cumulative %",
-          "---------+------------+-------+----+-------+---------+-------------",
-          "c172code | e16sex (1) |     1 |  5 | 10.87 |   12.20 |        12.20",
-          "         |            |     2 | 32 | 69.57 |   78.05 |        90.24",
-          "         |            |     3 |  4 |  8.70 |    9.76 |       100.00",
-          "         |            |  <NA> |  5 | 10.87 |    <NA> |         <NA>",
-          "---------+------------+-------+----+-------+---------+-------------",
-          "c172code | e16sex (2) |     1 |  3 |  5.56 |    6.12 |         6.12",
-          "         |            |     2 | 34 | 62.96 |   69.39 |        75.51",
-          "         |            |     3 | 12 | 22.22 |   24.49 |       100.00",
-          "         |            |  <NA> |  5 |  9.26 |    <NA> |         <NA>",
-          "-------------------------------------------------------------------"
-        )
+  test_that("data_tabulate print, collapse groups", {
+    x <-
+      data_tabulate(poorman::group_by(efc, e16sex), "c172code", collapse = TRUE)
+    out <- capture.output(print(x))
+    expect_equal(
+      out,
+      c(
+        "# Frequency Table",
+        "",
+        "Variable |      Group | Value |  N | Raw % | Valid % | Cumulative %",
+        "---------+------------+-------+----+-------+---------+-------------",
+        "c172code | e16sex (1) |     1 |  5 | 10.87 |   12.20 |        12.20",
+        "         |            |     2 | 32 | 69.57 |   78.05 |        90.24",
+        "         |            |     3 |  4 |  8.70 |    9.76 |       100.00",
+        "         |            |  <NA> |  5 | 10.87 |    <NA> |         <NA>",
+        "---------+------------+-------+----+-------+---------+-------------",
+        "c172code | e16sex (2) |     1 |  3 |  5.56 |    6.12 |         6.12",
+        "         |            |     2 | 34 | 62.96 |   69.39 |        75.51",
+        "         |            |     3 | 12 | 22.22 |   24.49 |       100.00",
+        "         |            |  <NA> |  5 |  9.26 |    <NA> |         <NA>",
+        "-------------------------------------------------------------------"
       )
-    })
+    )
+  })
 
-    test_that("data_tabulate print, collapse groups, dropl evels", {
-      x <- data_tabulate(poorman::group_by(efc, e16sex), "e42dep", collapse = TRUE, drop_levels = TRUE)
-      out <- capture.output(print(x))
-      expect_equal(
-        out,
-        c(
-          "# Frequency Table",
-          "",
-          "Variable |      Group | Value |  N | Raw % | Valid % | Cumulative %",
-          "---------+------------+-------+----+-------+---------+-------------",
-          "e42dep   | e16sex (1) |     1 |  2 |  4.35 |    4.44 |         4.44",
-          "         |            |     2 |  2 |  4.35 |    4.44 |         8.89",
-          "         |            |     3 |  8 | 17.39 |   17.78 |        26.67",
-          "         |            |     4 | 33 | 71.74 |   73.33 |       100.00",
-          "         |            |  <NA> |  1 |  2.17 |    <NA> |         <NA>",
-          "---------+------------+-------+----+-------+---------+-------------",
-          "e42dep   | e16sex (2) |     2 |  2 |  3.70 |    3.85 |         3.85",
-          "         |            |     3 | 20 | 37.04 |   38.46 |        42.31",
-          "         |            |     4 | 30 | 55.56 |   57.69 |       100.00",
-          "         |            |  <NA> |  2 |  3.70 |    <NA> |         <NA>",
-          "-------------------------------------------------------------------"
-        )
+  test_that("data_tabulate print, collapse groups, dropl evels", {
+    x <-
+      data_tabulate(
+        poorman::group_by(efc, e16sex),
+        "e42dep",
+        collapse = TRUE,
+        drop_levels = TRUE
       )
-    })
-  }
+    out <- capture.output(print(x))
+    expect_equal(
+      out,
+      c(
+        "# Frequency Table",
+        "",
+        "Variable |      Group | Value |  N | Raw % | Valid % | Cumulative %",
+        "---------+------------+-------+----+-------+---------+-------------",
+        "e42dep   | e16sex (1) |     1 |  2 |  4.35 |    4.44 |         4.44",
+        "         |            |     2 |  2 |  4.35 |    4.44 |         8.89",
+        "         |            |     3 |  8 | 17.39 |   17.78 |        26.67",
+        "         |            |     4 | 33 | 71.74 |   73.33 |       100.00",
+        "         |            |  <NA> |  1 |  2.17 |    <NA> |         <NA>",
+        "---------+------------+-------+----+-------+---------+-------------",
+        "e42dep   | e16sex (2) |     2 |  2 |  3.70 |    3.85 |         3.85",
+        "         |            |     3 | 20 | 37.04 |   38.46 |        42.31",
+        "         |            |     4 | 30 | 55.56 |   57.69 |       100.00",
+        "         |            |  <NA> |  2 |  3.70 |    <NA> |         <NA>",
+        "-------------------------------------------------------------------"
+      )
+    )
+  })
 }
+
+# select helpers ------------------------------
+test_that("data_tabulate regex", {
+  expect_equal(
+    data_tabulate(mtcars, select = "arb", regex = TRUE),
+    data_tabulate(mtcars, select = "carb")
+  )
+})
