@@ -237,3 +237,11 @@ test_that("unstandardize does nothing with characters and factors", {
     factor(c(1, 2))
   )
 })
+
+# select helpers ------------------------------
+test_that("standardize regex", {
+  expect_equal(
+    standardize(mtcars, select = "pg", regex = TRUE),
+    standardize(mtcars, select = "mpg")
+  )
+})
